@@ -838,6 +838,40 @@ class UpdateStateOperation(model._UpdateStateOperation):
         return super().close()
 
 
+class ListNamedShadowsForThingOperation(model._ListNamedShadowsForThingOperation):
+    """
+    ListNamedShadowsForThingOperation
+
+    Create with GreengrassCoreIPCClient.new_list_named_shadows_for_thing()
+    """
+
+    def activate(self, request: model.ListNamedShadowsForThingRequest) -> concurrent.futures.Future:
+        """
+        Activate this operation by sending the initial ListNamedShadowsForThingRequest message.
+
+        Returns a Future which completes with a result of None if the
+        request is successfully written to the wire, or an exception if
+        the request fails to send.
+        """
+        return self._activate(request)
+
+    def get_response(self) -> concurrent.futures.Future:
+        """
+        Returns a Future which completes with a result of ListNamedShadowsForThingResponse,
+        when the initial response is received, or an exception.
+        """
+        return self._get_response()
+
+    def close(self) -> concurrent.futures.Future:
+        """
+        Close the operation, whether or not it has completed.
+
+        Returns a Future which completes with a result of None
+        when the operation has closed.
+        """
+        return super().close()
+
+
 class SubscribeToComponentUpdatesStreamHandler(rpc.StreamResponseHandler):
     """
     Event handler for SubscribeToComponentUpdatesOperation
@@ -1240,6 +1274,16 @@ class GreengrassCoreIPCClient(rpc.Client):
         """
         return self._new_operation(UpdateStateOperation)
 
+    def new_list_named_shadows_for_thing(self) -> ListNamedShadowsForThingOperation:
+        """
+        Create a new ListNamedShadowsForThingOperation.
+
+        This operation will not send or receive any data until activate()
+        is called. Call activate() when you're ready for callbacks and
+        events to fire.
+        """
+        return self._new_operation(ListNamedShadowsForThingOperation)
+
     def new_subscribe_to_component_updates(self, stream_handler: SubscribeToComponentUpdatesStreamHandler) -> SubscribeToComponentUpdatesOperation:
         """
         Create a new SubscribeToComponentUpdatesOperation.
